==> nextcloud-12.0.4-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/zh_TW.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "活動",
    "An error occurred while loading activities" : "載入活動時發生錯誤",
    "No activity yet" : "尚無活動",
    "Load more activities" : "載入更多活動",
    "Copied!" : "已複製",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "按下 ⌘-C 來複製",
    "Press Ctrl-C to copy." : "按下 Ctrl-C 來複製",
    "Home" : "首頁",
    "{name} (invisible)" : "{name} (隱形)",
    "{name} (restricted)" : "{name} (受限)",
    "in {path}" : "在 {path}",
    "This stream will show events like additions, changes & shares" : "這邊會顯示檔案的新增、更動、分享等動態",
    "There are no events for this filter" : "在此篩選器下沒有活動",
    "Today" : "今天",
    "Yesterday" : "昨天",
    "Open file" : "開啟檔案",
    "Personal activity feed for %s" : "個人動態 %s",
    "Your feed URL is invalid" : "您的 Feed URL 是無效的",
    "Your settings have been updated." : "您的設定已更新",
    "Settings have been updated." : "設定已更新。",
    "Mail" : "電子郵件",
    "Stream" : "串流",
    "All activities" : "所有活動",
    "By others" : "由其他人",
    "By you" : "由您",
    "\"remote user\"" : "「遠端用戶」",
    "Hello %s" : "%s你好",
    "Hello %s," : "哈囉 %s ，",
    "There was some activity at %s" : "%s 的 activity",
    "_and %n more _::_and %n more _" : ["以及多%n個"],
    "Activity notification" : "活動通知",
    ", " : "，",
    "%s and %s" : "%s 與 %s",
    "Activity" : "活動",
    "Activity feed" : "動態",
    "Send activity emails" : "寄送啟動email",
    "Default settings" : "預設設定",
    "Configure the default activity settings for new users." : "為新使用者設置預設活動設定。",
    "List your own actions in the stream" : "列出屬於您的活動。",
    "Notify about your own actions via email" : "透過郵件來通知有關於您的活動狀態",
    "You need to set up your email address before you can receive notification emails." : "您必須先設定電子郵件，才能接收通知。",
    "Send emails:" : "寄送郵件：",
    "As soon as possible" : "盡快",
    "Hourly" : "每小時",
    "Daily" : "每日",
    "Weekly" : "每週",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "選擇你希望接受到電郵通知或者在應用中顯示的活動。",
    "Choose which activities you want to see in your stream." : "請選擇您想在您串流中看到的活動",
    "Settings" : "設定",
    "Enable RSS feed" : "啟用 RSS feed",
    "RSS feed" : "RSS摘要",
    "No more events to load" : "已載入所有事件",
    "Files" : "檔案",
    "Error loading activities" : "載入活動錯誤",
    "No activities" : "沒有活動",
    "You are receiving this email because the following things happened at %s" : "您會收到郵件是因為 %s 發生此事件",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* 和其他 %n 個"]
},
"nplurals=1; plural=0;");

==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/zh_TW.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "活動",
    "An error occurred while loading activities" : "載入活動時發生錯誤",
    "No activity yet" : "尚無活動",
    "Load more activities" : "載入更多活動",
    "Copied!" : "已複製",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "按下 ⌘-C 來複製",
    "Press Ctrl-C to copy." : "按下 Ctrl-C 來複製",
    "Home" : "首頁",
    "{name} (invisible)" : "{name} (隱形)",
    "{name} (restricted)" : "{name} (受限)",
    "in {path}" : "在 {path}",
    "This stream will show events like additions, changes & shares" : "這邊會顯示檔案的新增、更動、分享等動態",
    "There are no events for this filter" : "在此篩選器下沒有活動",
    "Today" : "今天",
    "Yesterday" : "昨天",
    "Open file" : "開啟檔案",
    "Personal activity feed for %s" : "個人動態 %s",
    "Your feed URL is invalid" : "您的 Feed URL 是無效的",
    "Your settings have been updated." : "您的設定已更新",
    "Settings have been updated." : "設定已更新。",
    "Mail" : "電子郵件",
    "Stream" : "串流",
    "All activities" : "所有活動",
    "By others" : "由其他人",
    "By you" : "由您",
    "\"remote user\"" : "「遠端用戶」",
    "Hello %s" : "%s你好",
    "Hello %s," : "哈囉 %s ，",
    "There was some activity at %s" : "%s 的活動",
    "_and %n more _::_and %n more _" : ["以及多%n個"],
    "Activity notification" : "活動通知",
    ", " : "，",
    "%s and %s" : "%s 與 %s",
    "Activity" : "活動",
    "Activity feed" : "動態",
    "Send activity emails" : "寄送有關活動的郵件",
    "Default settings" : "預設設定",
    "Configure the default activity settings for new users." : "為新使用者設置預設活動設定。",
    "List your own actions in the stream" : "列出屬於您的活動。",
    "Notify about your own actions via email" : "透過郵件來通知有關於您的活動狀態",
    "You need to set up your email address before you can receive notification emails." : "您必須先設定電子郵件，才能接收通知。",
    "Send emails:" : "寄送郵件：",
    "As soon as possible" : "盡快",
    "Hourly" : "每小時",
    "Daily" : "每日",
    "Weekly" : "每週",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "選擇你希望接受到電郵通知或者在應用中顯示的活動。",
    "Choose which activities you want to see in your stream." : "請選擇您想在您串流中看到的活動",
    "Settings" : "設定",
    "Enable RSS feed" : "啟用 RSS feed",
    "RSS feed" : "RSS 摘要",
    "No more events to load" : "已載入所有事件",
    "Files" : "檔案",
    "Error loading activities" : "載入活動錯誤",
    "No activities" : "沒有活動",
    "You are receiving this email because the following things happened at %s" : "您會收到郵件是因為 %s 發生此事件",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* 和其他 %n 個"]
},
"nplurals=1; plural=0;");
